/*
** Module   : SequenceHandler.java
** Abstract : Interface for all sequence handler implementations.
**
** Copyright (c) 2012, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------Description------------------------
** 001 OM  20121128 Created initial version.
*/

package com.goldencode.p2j.persist.sequence;

import com.goldencode.p2j.util.*;

/**
 * Implementations of this interface are use different strategies for 
 * handling 4GL sequences, depending on the backing database system.
 * The interface declares the three methods that abstracts the three actions 
 * that can be applied to a sequence <code>CURRENT-VALUE</code>, 
 * <code>NEXT-VALUE</code> and <code>CURRENT-VALUE</code> statement. 
 */
public class SequenceHandler
{
   /**
    * Queries the current value of a sequence. The base class always returns
    * unknown value.
    * 
    * @param   seqName
    *          The name of the sequence.
    * @param   ldbName
    *          The database to which the sequence belongs to. If is null then
    *          the first connected database is assumed.
    *
    * @return  unknown value
    */
   public int64 getCurrentValue(String seqName, String ldbName)
   {
      return new int64();
   }

   /**
    * Computes and returns the next value of a sequence. The base class 
    * always returns unknown value.
    * @param   seqName
    *          The name of the sequence.
    * @param   ldbName
    *          The database to which the sequence belongs to. If is null then
    *          the first connected database is assumed.
    *
    * @return unknown value
    */
   public int64 getNextValue(String seqName, String ldbName)
   {
      return new int64();
   }

   /**
    * Initialize (reset) the current value of a sequence. The base class 
    * does nothing.
    * @param   seqName
    *          The name of the sequence.
    * @param   ldbName
    *          The database to which the sequence belongs to. If is null then
    *          the first connected database is assumed.
    * @param   newVal
    *          The value the sequence will be reseted to.
    */
   public void setValue(String seqName, String ldbName, long newVal)
   {
   }

   /**
    * Test whether the database contains a sequence This is useful to check
    * identify the correct database/sequences when a 4GL static function /
    * statement is called without the database parameter. The base class 
    * always returns false.
    * @param   seqName
    *          The name of the sequence.
    * @param   ldbName
    *          The database to which the sequence belongs to. If is null then
    *          the first connected database is assumed.
    *
    * @return false
    */
   public boolean contains(String ldbName, String seqName)
   {
      return false;
   }
}
